@@ -75,7 +75,9 @@ class Model : public QStringListModel
 {
     Q_OBJECT
 public:
-    enum SpecialRoles { PluginName = Qt::UserRole };
+    enum SpecialRoles {
+        PluginName = Qt::UserRole
+    };
 
     explicit Model(Navigator *parentNavigator = nullptr)
         : QStringListModel(parentNavigator)
@@ -159,7 +161,6 @@ public:
     explicit SortFilterProxyModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
     {
-        setDynamicSortFilter(true);
         sort(0);
     }
 
@@ -245,7 +246,6 @@ private:
 
 Navigator::Navigator(SidePaneBase *parent)
     : QListView(parent)
-    , mSidePane(parent)
     , mModel(new Model(this))
 {
     setViewport(new QWidget(this));
@@ -380,10 +380,10 @@ void Navigator::setCurrentPlugin(const QString &plugin)
 
 QSize Navigator::sizeHint() const
 {
-    //### TODO: We can cache this value, so this reply is faster. Since here we won't
-    //          have too many elements, it is not that important. When caching this value
-    //          make sure it is updated correctly when new rows have been added or
-    //          removed. (ereslibre)
+    // ### TODO: We can cache this value, so this reply is faster. Since here we won't
+    //           have too many elements, it is not that important. When caching this value
+    //           make sure it is updated correctly when new rows have been added or
+    //           removed. (ereslibre)
 
     int maxWidth = 0;
     const int numberOfRows(model()->rowCount());
